#ifndef INTEGRANDS_H_INCLUDED
#define INTEGRANDS_H_INCLUDED

#include "curves.h"
#include "interval.hpp"
#include "itaylor.hpp"
#include <iostream>

// Integrand of A_{1}: itaylor data type
itaylor integrand_A1_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{1}: interval data type
interval integrand_A1_fast(const interval& x, const ParameterSet& p, int& flag);

// Integrand of A_{2}: itaylor data type
itaylor integrand_A2_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{2}: interval data type
interval integrand_A2_fast(const interval& x, const ParameterSet& p, int& flag);

// Integrand of A_{3}: itaylor data type
itaylor integrand_A3_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{3}: interval data type
interval integrand_A3_fast(const interval& x, const ParameterSet& p, int& flag);

// Integrand of A_{1} (singular part - numerator): itaylor data type
itaylor integrand_A1_singularity_num_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{1} (singular part - denominator): itaylor data type
itaylor integrand_A1_singularity_den_slow(const interval& x, const ParameterSet& p, int order, int& flag);

// Integrand of A_{2} (singular part - numerator): itaylor data type
itaylor integrand_A2_singularity_num_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{2} (singular part - denominator): itaylor data type
itaylor integrand_A2_singularity_den_slow(const interval& x, const ParameterSet& p, int order, int& flag);

// Integrand of A_{3} (singular part - numerator): itaylor data type
itaylor integrand_A3_singularity_num_slow(const interval& x, const ParameterSet& p, int order, int& flag);
// Integrand of A_{3} (singular part - denominator): itaylor data type
itaylor integrand_A3_singularity_den_slow(const interval& x, const ParameterSet& p, int order, int& flag);

#endif
