#ifndef CURVES_H_INCLUDED
#define CURVES_H_INCLUDED

#include "interval.hpp"
#include "itaylor.hpp"
#include "dim2taylor.hpp"
#include <iostream>
#include <vector>

using namespace cxsc;
using namespace std;
using namespace taylor;

typedef struct {
  double abs_tol;
  double rel_tol;
  interval epsilon;
  interval A;
  interval Left;
  interval Right;
} ParameterSet;


// Parametrization of the curve: itaylor data type
itaylor z1(const itaylor& x, const ParameterSet& p);
itaylor z2(const itaylor& x, const ParameterSet& p);
itaylor Delta_z1(const ivector& v, const ParameterSet& p, int order);

// Parametrization of the curve: interval data type coming from interval
interval z1(const interval& v, const ParameterSet& p);
interval z2(const interval& v, const ParameterSet& p);
// This computes zi(v[1])-zi(v[1]+v[2])
interval Delta_z1(const ivector& v, const ParameterSet& p);

// Parametrization of the curve: dim2taylor data type coming from dim2taylor
dim2taylor z1(const dim2taylor& v, const ParameterSet& p);
dim2taylor z2(const dim2taylor& v, const ParameterSet& p);
// This computes zi(v[1])-zi(v[1]+v[2])
dim2taylor Delta_z1(const dim2taylor_vector& v, const ParameterSet& p);


#endif
