#include "curves.h"


// Parametrization of the curve: itaylor data type
itaylor z1(const itaylor& x, const ParameterSet& p){
  return x - sin(x)*((interval)1.0+p.epsilon);
}

itaylor z2(const itaylor& x, const ParameterSet& p){
  return p.A*sin((interval)2.0*x);
}

// returns z1(v[1])-z1(v[1]+v[2]) exploiting the cancelation.
// The return type is an itaylor of order 'order' built on v[1], 
// so that if we want to compute z1'(v[1])-z1'(v[1]+v[2]) for example 
// (or any number of derivatives) we are good because it equals 
// \pa_{v[1]}(z1(v[1])-z1(v[1]+v[2])). Note that this is not true if 
// the itaylor is built on v[2].
itaylor Delta_z1(const ivector& v, const ParameterSet& p, int order){
  itaylor v1_it = itaylor(order,v[1]);
  return -v[2]-((interval)1.0+p.epsilon)*(sin(v1_it)-sin(v1_it+v[2]));
}

// Parametrization of the curve: interval data type coming from interval
interval z1(const interval& v, const ParameterSet& p){
  return v - sin(v)*((interval)1.0+p.epsilon);
}

interval z2(const interval& v, const ParameterSet &p){
  return p.A*sin((interval)2.0*v);  
}

interval Delta_z1(const ivector& v, const ParameterSet& p){
  return -v[2]-((interval)1.0+p.epsilon)*(sin(v[1])-sin(v[1]+v[2]));
}

// Parametrization of the curve: dim2taylor data type.
dim2taylor z1(const dim2taylor& v, const ParameterSet& p){
  return v - sin(v)*((interval)1.0+p.epsilon);
}

dim2taylor z2(const dim2taylor& v, const ParameterSet &p){
  return p.A*sin((interval)2.0*v);
}

// This computes zi(v[1])-zi(v[1]+v[2]) exploiting the cancelation.
dim2taylor Delta_z1(const dim2taylor_vector& v, const ParameterSet& p){
  return -v[2]-((interval)1.0+p.epsilon)*(sin(v[1])-sin(v[1]+v[2]));
}


