#include "integrands.h"

///////////// FAST INTEGRANDS: interval data type

// iv(1) = y, iv(2) = z
interval integrand_B11_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); 
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p); 
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0); 
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);

  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*sqr(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
    
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B12_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); 
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p); 
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); //interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(D2Z10-D2Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B13_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p); 
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); // interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B14_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B15_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B16_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B21_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B22_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); // interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B23_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*power(DZ10-DZ1z,3);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*power(DDeltaZ1,3);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B24_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)2.0*num1/den1*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B25_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B31_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);

  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B32_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); // interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B33_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B34_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(3,iv[1]); itaylor z_it = itaylor(3,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
//  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval D3Z1y = get_j_derive(ITZ1y,3); interval D3Z1z = get_j_derive(ITZ1z,3);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(3,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
//  interval D2Z10 = get_j_derive(ITZ10,2);
  interval D3Z10 = get_j_derive(ITZ10,3);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 3);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  interval D3DeltaZ1 = get_j_derive(ITDeltaZ1,3);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D3Z10-D3Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D3DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B35_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B41_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B42_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B43_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B44_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z)*sinh(-Z2z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B45_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*cosh(-Z2z)*sqr(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*cosh(Z2y-Z2zy)*sqr(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}


// iv(1) = y, iv(2) = z
interval integrand_B46_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  interval D2Z2y = get_j_derive(ITZ2y,2); interval D2Z2z = get_j_derive(ITZ2z,2); interval D2Z2zy = get_j_derive(ITZ2zy,2);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/* interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(D2Z20-D2Z2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(D2Z2y-D2Z2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B47_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)2.0*num1/den1*(num2/power(den2,3)-num3/power(den3,3));
}

// iv(1) = y, iv(2) = z
interval integrand_B51_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = cos(-Z1y)*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B52_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); // interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B53_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*cos(-Z1z)*power(DZ10-DZ1z,3);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*cos(DeltaZ1)*power(DDeltaZ1,3);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)(-2.0)*num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B54_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sqr(sin(-Z1z))*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sqr(sin(DeltaZ1))*(DDeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)(-2.0)*num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B55_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)(2.0)*num1/den1*(num2/power(den2,3)-num3/power(den3,3));
}

// iv(1) = y, iv(2) = z
interval integrand_B61_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  interval DeltaZ1 = Delta_z1(iv, p);
  
  interval num1 = cos(-Z1y)*sqr(DZ10-DZ1y)*sinh(-Z2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B62_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
//  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); // interval D2Z1z = get_j_derive(ITZ1z,2);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  interval DeltaZ1 = Delta_z1(iv, p);
  
  interval num1 = sin(-Z1y)*(D2Z10-D2Z1y)*sinh(-Z2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B63_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  interval DeltaZ1 = Delta_z1(iv, p);
  
  interval num1 = sin(-Z1y)*(DZ10-DZ1y)*cosh(-Z2y)*(DZ20-DZ2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


// iv(1) = y, iv(2) = z
interval integrand_B64_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  interval DeltaZ1 = Delta_z1(iv, p);
  
  interval num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)2.0*num1/power(den1,3)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B65_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*(DZ10-DZ1z)*(DZ20-DZ2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*(DDeltaZ1)*(DZ2y-DZ2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B66_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]); itaylor yz_it = itaylor(2,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  interval D2Z2y = get_j_derive(ITZ2y,2); interval D2Z2z = get_j_derive(ITZ2z,2); interval D2Z2zy = get_j_derive(ITZ2zy,2);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/*  interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);

  interval DeltaZ1 = Delta_z1(iv, p);
  
  interval num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z20-D2Z2z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2Z2y-D2Z2zy);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B67_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

// iv(1) = y, iv(2) = z
interval integrand_B71_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sin(-Z1y)*cos(-Z1y)*sqr(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)(-2.0)*num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B72_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); // interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sqr(sin(-Z1y))*(D2Z10-D2Z1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B73_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); // interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sqr(sin(-Z1y))*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return (interval)(2.0)*num1/power(den1,3)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B74_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B75_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(2,iv[1]); itaylor z_it = itaylor(2,iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1);
  interval D2Z1y = get_j_derive(ITZ1y,2); interval D2Z1z = get_j_derive(ITZ1z,2);
  interval Z2y = z2(iv[1],p); interval Z2z = z2(iv[2],p); interval Z2zy = z2(iv[1]+iv[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 2);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  interval D2DeltaZ1 = get_j_derive(ITDeltaZ1,2);
  
  interval num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(D2DeltaZ1);
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

// iv(1) = y, iv(2) = z
interval integrand_B76_fast(const ivector& iv, const ParameterSet& p, int& flag){
  itaylor y_it = itaylor(1,iv[1]); itaylor z_it = itaylor(1,iv[2]); itaylor yz_it = itaylor(1,iv[1]+iv[2]);
  itaylor ITZ1y = z1(y_it,p); itaylor ITZ1z = z1(z_it,p); itaylor ITZ1zy = z1(yz_it,p);
  interval Z1y = get_j_derive(ITZ1y,0); interval Z1z = get_j_derive(ITZ1z,0); interval Z1zy = get_j_derive(ITZ1zy,0);
  interval DZ1y = get_j_derive(ITZ1y,1); interval DZ1z = get_j_derive(ITZ1z,1); interval DZ1zy = get_j_derive(ITZ1zy,1);  
  itaylor ITZ2y = z2(y_it,p); itaylor ITZ2z = z2(z_it,p); itaylor ITZ2zy = z2(yz_it,p);
  interval Z2y = get_j_derive(ITZ2y,0); interval Z2z = get_j_derive(ITZ2z,0); interval Z2zy = get_j_derive(ITZ2zy,0);
  interval DZ2y = get_j_derive(ITZ2y,1); interval DZ2z = get_j_derive(ITZ2z,1); interval DZ2zy = get_j_derive(ITZ2zy,1);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  itaylor ITDeltaZ1 = Delta_z1(iv, p, 1);
  
  interval DeltaZ1 = get_j_derive(ITDeltaZ1,0);
  interval DDeltaZ1 = get_j_derive(ITDeltaZ1,1);
  
  interval num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  interval den1 = cosh(-Z2y)-cos(-Z1y);
  interval num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  interval den2 = cosh(-Z2z)-cos(-Z1z);
  interval num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  interval den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1 || 0.0 <= den2 || 0.0 <= den3){
    flag |= 1;
    return interval(0.0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}



///////////// SLOW INTEGRANDS: dim2taylor data type



// iv(1) = y, iv(2) = z
dim2taylor integrand_B11_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*sqr(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
    
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B12_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(D2Z10-D2Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B13_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);

  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B14_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);

  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B15_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
   
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B16_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B21_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B22_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B23_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*cube(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*cube(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B24_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)2.0*num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B25_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B31_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B32_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  DZ2y = trunc(DZ2y,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B33_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B34_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+3,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
//  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  dim2taylor D3Z1y = diff(Z1y,3,0); dim2taylor D3Z1z = diff(Z1z,0,3);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(3,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
//  interval D2Z10 = get_j_derive(ITZ10,2);
  interval D3Z10 = get_j_derive(ITZ10,3);
  // Now, Z1, Z2, DZ1 and D3Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D3DeltaZ1 = diff(DeltaZ1,3,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D3Z10-D3Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D3DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/den1*(num2/den2-num3/den3);
}

dim2taylor integrand_B35_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B41_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B42_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B43_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B44_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B45_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*cosh(-Z2z)*sqr(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*cosh(Z2y-Z2zy)*sqr(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B46_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  dim2taylor D2Z2y = diff(Z2y,2,0); dim2taylor D2Z2z = diff(Z2z,0,2); dim2taylor D2Z2zy = diff(Z2zy,2,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/* interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(D2Z20-D2Z2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(D2Z2y-D2Z2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B47_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)2.0*num1/den1*(num2/cube(den2)-num3/cube(den3));
}

dim2taylor integrand_B51_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B52_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B53_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*cos(-Z1z)*cube(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*cos(DeltaZ1)*cube(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)(-2.0)*num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B54_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)(-2.0)*num1/den1*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B55_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)(2.0)*num1/den1*(num2/cube(den2) - num3/cube(den3));
}

dim2taylor integrand_B61_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = cos(-Z1y)*sqr(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B62_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order); 
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(D2Z10-D2Z1y)*sinh(-Z2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B63_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*cosh(-Z2y)*(DZ20-DZ2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B64_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)2.0*num1/cube(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B65_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B66_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  dim2taylor D2Z2y = diff(Z2y,2,0); dim2taylor D2Z2z = diff(Z2z,0,2); dim2taylor D2Z2zy = diff(Z2zy,2,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/* interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z20-D2Z2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2Z2y-D2Z2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}


dim2taylor integrand_B67_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);

  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

dim2taylor integrand_B71_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*cos(-Z1y)*sqr(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)(-2.0)*num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B72_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(D2Z10-D2Z1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B73_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return (interval)(2.0)*num1/cube(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B74_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);

  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B75_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);

  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return -num1/sqr(den1)*(num2/den2-num3/den3);
}

dim2taylor integrand_B76_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  if (0.0 <= den1[0][0] || 0.0 <= den2[0][0] || 0.0 <= den3[0][0]){
    flag |= 1;
    return dim2taylor(0);
  }
  return num1/sqr(den1)*(num2/sqr(den2)-num3/sqr(den3));
}

//////////// DENOMINATOR SINGULARITIES: dim2taylor data type


dim2taylor integrand_B11_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B12_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B13_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B14_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B15_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B16_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B21_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B22_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B23_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B24_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B25_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B31_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B32_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B33_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B34_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*den2*den3;
}

dim2taylor integrand_B35_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B41_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B42_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*sqr(den2*den3);
}

dim2taylor integrand_B43_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B44_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B45_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B46_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B47_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*cube(den2*den3);
}

dim2taylor integrand_B51_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B52_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*sqr(den2*den3);
}

dim2taylor integrand_B53_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B54_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*sqr(den2*den3);
}

dim2taylor integrand_B55_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return den1*cube(den2*den3);
}

dim2taylor integrand_B61_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B62_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B63_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B64_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return cube(den1)*den2*den3;
}

dim2taylor integrand_B65_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B66_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B67_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*sqr(den2*den3);
}

dim2taylor integrand_B71_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B72_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B73_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return cube(den1)*den2*den3;
}

dim2taylor integrand_B74_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B75_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*den2*den3;
}

dim2taylor integrand_B76_singularity_den_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  
  dim2taylor den1 = cosh(-Z2y)-cos(-Z1y);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return sqr(den1)*sqr(den2*den3);
}


//////////// NUMERATOR SINGULARITIES: dim2taylor data type


dim2taylor integrand_B11_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*sqr(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);

  return -num1*(num2*den3-den2*num3);
}


dim2taylor integrand_B12_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(D2Z10-D2Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}


dim2taylor integrand_B13_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);

  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B14_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);

  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B15_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
   
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B16_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B21_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B22_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B23_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*cube(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*cube(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B24_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)2.0*num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B25_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p); dim2taylor Z1zy = z1(dv[1]+dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1); dim2taylor DZ1zy = diff(Z1zy,1,0);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order); Z1zy = trunc(Z1zy,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B31_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B32_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  DZ2y = trunc(DZ2y,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B33_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B34_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+3,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
//  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  dim2taylor D3Z1y = diff(Z1y,3,0); dim2taylor D3Z1z = diff(Z1z,0,3);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(3,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
//  interval D2Z10 = get_j_derive(ITZ10,2);
  interval D3Z10 = get_j_derive(ITZ10,3);
  // Now, Z1, Z2, DZ1 and D3Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D3DeltaZ1 = diff(DeltaZ1,3,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D3Z10-D3Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D3DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B35_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B41_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B42_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B43_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B44_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z)*sinh(-Z2z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B45_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*cosh(-Z2z)*sqr(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*cosh(Z2y-Z2zy)*sqr(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B46_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  dim2taylor D2Z2y = diff(Z2y,2,0); dim2taylor D2Z2z = diff(Z2z,0,2); dim2taylor D2Z2zy = diff(Z2zy,2,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/* interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(D2Z20-D2Z2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(D2Z2y-D2Z2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B47_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*sinh(-Z2z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)2.0*num1*(num2*cube(den3)-cube(den2)*num3);
}

dim2taylor integrand_B51_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = cos(-Z1y)*(DZ10-DZ1y);
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B52_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B53_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sin(-Z1z)*cos(-Z1z)*cube(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*cos(DeltaZ1)*cube(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)(-2.0)*num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B54_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*(DZ10-DZ1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*(DDeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)(-2.0)*num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B55_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y);
  dim2taylor num2 = sqr(sin(-Z1z))*sqr(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sqr(sin(DeltaZ1))*sqr(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy) - cos(DeltaZ1);
  
  return (interval)(2.0)*num1*(num2*cube(den3)-cube(den2)*num3);
}

dim2taylor integrand_B61_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = cos(-Z1y)*sqr(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B62_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  interval D2Z10 = get_j_derive(ITZ10,2); // interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(D2Z10-D2Z1y)*sinh(-Z2y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B63_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*cosh(-Z2y)*(DZ20-DZ2y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B64_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)2.0*num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B65_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor num2 = cos(-Z1z)*(DZ10-DZ1z)*(DZ20-DZ2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*(DDeltaZ1)*(DZ2y-DZ2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B66_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  dim2taylor D2Z2y = diff(Z2y,2,0); dim2taylor D2Z2z = diff(Z2z,0,2); dim2taylor D2Z2zy = diff(Z2zy,2,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  DZ2y = trunc(DZ2y,order); DZ2z = trunc(DZ2z,order); DZ2zy = trunc(DZ2zy,order);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
/* interval D2Z10 = get_j_derive(ITZ10,2); */ interval D2Z20 = get_j_derive(ITZ20,2);
  // Now, Z1, Z2, DZ1, DZ2 and D2Z2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv_low, p);
  
  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor num2 = sin(-Z1z)*(D2Z20-D2Z2z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2Z2y-D2Z2zy);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B67_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);

  dim2taylor num1 = sin(-Z1y)*(DZ10-DZ1y)*sinh(-Z2y);
  dim2taylor num2 = sin(-Z1z)*(DZ20-DZ2z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DZ2y-DZ2zy)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*sqr(den3)-sqr(den2)*num3);
}

dim2taylor integrand_B71_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sin(-Z1y)*cos(-Z1y)*sqr(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)(-2.0)*num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B72_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); // dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(D2Z10-D2Z1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B73_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0);
  Z2y = trunc(Z2y,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y)*(sinh(-Z2y)*(DZ20-DZ2y)+sin(-Z1y)*(DZ10-DZ1y));
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return (interval)(2.0)*num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B74_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  // Now, Z1, Z2 and DZ1 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);

  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor num2 = cos(-Z1z)*sqr(DZ10-DZ1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = cos(DeltaZ1)*sqr(DDeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B75_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+2,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  dim2taylor D2Z1y = diff(Z1y,2,0); dim2taylor D2Z1z = diff(Z1z,0,2);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  DZ1y = trunc(DZ1y,order); DZ1z = trunc(DZ1z,order);
  dim2taylor Z2y = z2(dv_low[1],p); dim2taylor Z2z = z2(dv_low[2],p); dim2taylor Z2zy = z2(dv_low[1]+dv_low[2],p);
  itaylor x_it0 = itaylor(2,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1);
  interval D2Z10 = get_j_derive(ITZ10,2);
  // Now, Z1, Z2, DZ1 and D2Z1 are order 'order' dim2taylors

  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  dim2taylor D2DeltaZ1 = diff(DeltaZ1,2,0);
  DeltaZ1 = trunc(DeltaZ1,order); DDeltaZ1 = trunc(DDeltaZ1,order);

  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(D2Z10-D2Z1z);
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(D2DeltaZ1);
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return -num1*(num2*den3-den2*num3);
}

dim2taylor integrand_B76_singularity_num_slow(const ivector& iv, const ParameterSet& p, int order, int& flag){
  dim2taylor_vector dv; dv = init_var(order+1,(ivector&)iv);
  dim2taylor_vector dv_low; dv_low = init_var(order,(ivector&)iv);
  dim2taylor Z1y = z1(dv[1],p); dim2taylor Z1z = z1(dv[2],p);
  dim2taylor DZ1y = diff(Z1y,1,0); dim2taylor DZ1z = diff(Z1z,0,1);
  Z1y = trunc(Z1y,order); Z1z = trunc(Z1z,order);
  dim2taylor Z2y = z2(dv[1],p); dim2taylor Z2z = z2(dv[2],p); dim2taylor Z2zy = z2(dv[1]+dv[2],p);
  dim2taylor DZ2y = diff(Z2y,1,0); dim2taylor DZ2z = diff(Z2z,0,1); dim2taylor DZ2zy = diff(Z2zy,1,0);
  Z2y = trunc(Z2y,order); Z2z = trunc(Z2z,order); Z2zy = trunc(Z2zy,order);
  itaylor x_it0 = itaylor(1,(interval)0.0);
  itaylor ITZ10 = z1(x_it0,p); itaylor ITZ20 = z2(x_it0,p);
  interval DZ10 = get_j_derive(ITZ10,1); interval DZ20 = get_j_derive(ITZ20,1);
  // Now, Z1, Z2, DZ1 and DZ2 are order 'order' dim2taylors
  
  dim2taylor DeltaZ1 = Delta_z1(dv, p);
  dim2taylor DDeltaZ1 = diff(DeltaZ1,1,0);
  DeltaZ1 = trunc(DeltaZ1,order);
  
  dim2taylor num1 = sqr(sin(-Z1y))*(DZ10-DZ1y);
  dim2taylor num2 = sin(-Z1z)*(DZ10-DZ1z)*(sinh(-Z2z)*(DZ20-DZ2z)+sin(-Z1z)*(DZ10-DZ1z));
  dim2taylor den2 = cosh(-Z2z)-cos(-Z1z);
  dim2taylor num3 = sin(DeltaZ1)*(DDeltaZ1)*(sinh(Z2y-Z2zy)*(DZ2y-DZ2zy)+sin(DeltaZ1)*(DDeltaZ1));
  dim2taylor den3 = cosh(Z2y-Z2zy)-cos(DeltaZ1);
  
  return num1*(num2*sqr(den3)-sqr(den2)*num3);
}


